@@ -41,9 +41,12 @@ import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
 import java.util.ArrayList;
 import java.util.Enumeration;
+import java.util.HashSet;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Set;
 
+import javax.imageio.ImageIO;
 import javax.swing.BorderFactory;
 import javax.swing.Box;
 import javax.swing.ButtonGroup;
@@ -150,6 +153,9 @@ import mobac.utilities.I18nUtils;
 import mobac.utilities.Utilities;
 
 public class MainGUI extends JFrame implements MapEventListener {
+	{
+		ImageIO.setUseCache(false);
+	}
 
 	private static final long serialVersionUID = 1L;
 
@@ -181,10 +187,10 @@ public class MainGUI extends JFrame implements MapEventListener {
 	public final JAtlasTree jAtlasTree = new JAtlasTree(previewMap);
 
 	private JCheckBox wgsGridCheckBox;
-	private JComboBox wgsGridCombo;
+	private JComboBox<WgsDensity> wgsGridCombo;
 
 	private JLabel zoomLevelText;
-	private JComboBox gridZoomCombo;
+	private JComboBox<GridZoom> gridZoomCombo;
 	private JSlider zoomSlider;
 	private JMapSourceTree mapSourceTree;
 	private JAtlasNameField atlasNameTextField;
@@ -340,7 +346,7 @@ public class MainGUI extends JFrame implements MapEventListener {
 		zoomLevelText.setToolTipText(I18nUtils.localizedStringForKey("map_ctrl_zoom_level_title_tips"));
 
 		// grid zoom combo
-		gridZoomCombo = new JComboBox();
+		gridZoomCombo = new JComboBox<>();
 		gridZoomCombo.setEditable(false);
 		gridZoomCombo.addActionListener(new GridZoomComboListener());
 		gridZoomCombo.setToolTipText(I18nUtils.localizedStringForKey("map_ctrl_zoom_grid_tips"));
@@ -365,7 +371,7 @@ public class MainGUI extends JFrame implements MapEventListener {
 		});
 
 		// WGS Grid combo
-		wgsGridCombo = new JComboBox(WgsDensity.values());
+		wgsGridCombo = new JComboBox<>(WgsDensity.values());
 		wgsGridCombo.setMaximumRowCount(WgsDensity.values().length);
 		wgsGridCombo.setVisible(s.enabled);
 		wgsGridCombo.setSelectedItem(s.density);
@@ -819,6 +825,14 @@ public class MainGUI extends JFrame implements MapEventListener {
 				}
 			}
 		}
+
+		Set<String> trustedCertificatesLowerCase = new HashSet<>();
+		for (String hash : settings.trustedCertificates) {
+			trustedCertificatesLowerCase.add(hash.toLowerCase());
+		}
+		settings.trustedCertificates.clear();
+		settings.trustedCertificates.addAll(trustedCertificatesLowerCase);
+
 		coordinatesPanel.setNumberFormat(settings.coordinateNumberFormat);
 
 		tileImageParametersPanel.loadSettings();
