@@ -66,6 +66,9 @@ import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.xml.bind.JAXBException;
 
+import org.apache.log4j.Level;
+import org.apache.log4j.Logger;
+
 import mobac.StartMOBAC;
 import mobac.exceptions.UpdateFailedException;
 import mobac.gui.MainGUI;
@@ -89,9 +92,6 @@ import mobac.utilities.GUIExceptionHandler;
 import mobac.utilities.I18nUtils;
 import mobac.utilities.Utilities;
 
-import org.apache.log4j.Level;
-import org.apache.log4j.Logger;
-
 public class SettingsGUI extends JDialog {
 	private static final long serialVersionUID = -5227934684609357198L;
 
@@ -155,9 +155,9 @@ public class SettingsGUI extends JDialog {
 
 	private final Settings settings = Settings.getInstance();
 
-	private JComboBox unitSystem;
+	private JComboBox<UnitSystem> unitSystem;
 
-	private JComboBox languageCombo;
+	private JComboBox<SupportLocale> languageCombo;
 
 	private JButton mapSourcesOnlineUpdate;
 	private JTextField osmHikingTicket;
@@ -174,10 +174,10 @@ public class SettingsGUI extends JDialog {
 
 	private JTextField atlasOutputDirectory;
 
-	private JComboBox threadCount;
-	private JComboBox bandwidth;
+	private JComboBox<Integer> threadCount;
+	private JComboBox<Bandwidth> bandwidth;
 
-	private JComboBox proxyType;
+	private JComboBox<ProxyType> proxyType;
 	private JTextField proxyHost;
 	private JTextField proxyPort;
 
@@ -191,11 +191,11 @@ public class SettingsGUI extends JDialog {
 
 	private JTabbedPane tabbedPane;
 
-	private JList enabledMapSources;
+	private JList<MapSource> enabledMapSources;
 
 	private MapSourcesListModel enabledMapSourcesModel;
 
-	private JList disabledMapSources;
+	private JList<MapSource> disabledMapSources;
 
 	private MapSourcesListModel disabledMapSourcesModel;
 
@@ -283,7 +283,7 @@ public class SettingsGUI extends JDialog {
 		// Language Panel
 		JPanel languagePanel = new JPanel(new GridBagLayout());
 		languagePanel.setBorder(createSectionBorder(I18nUtils.localizedStringForKey("set_display_language")));
-		languageCombo = new JComboBox(SupportLocale.values());
+		languageCombo = new JComboBox<>(SupportLocale.values());
 		languageCombo.setToolTipText(I18nUtils.localizedStringForKey("set_display_language_choose_tips"));
 		languageCombo.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
@@ -306,8 +306,8 @@ public class SettingsGUI extends JDialog {
 						try {
 							final String javaBin = System.getProperty("java.home") + File.separator + "bin"
 									+ File.separator + "java";
-							final File currentJar = new File(SettingsGUI.class.getProtectionDomain().getCodeSource()
-									.getLocation().toURI());
+							final File currentJar = new File(
+									SettingsGUI.class.getProtectionDomain().getCodeSource().getLocation().toURI());
 
 							/* is it a jar file? */
 							if (currentJar.getName().endsWith(".jar")) {
@@ -345,9 +345,9 @@ public class SettingsGUI extends JDialog {
 		languagePanel.add(Box.createHorizontalGlue(), GBC.eol().fill(GBC.HORIZONTAL));
 
 		UnitSystem[] us = UnitSystem.values();
-		unitSystem = new JComboBox(us);
-		unitSystemPanel
-				.add(new JLabel(I18nUtils.localizedStringForKey("set_display_unit_system_scale_bar")), GBC.std());
+		unitSystem = new JComboBox<>(us);
+		unitSystemPanel.add(new JLabel(I18nUtils.localizedStringForKey("set_display_unit_system_scale_bar")),
+				GBC.std());
 		unitSystemPanel.add(unitSystem, GBC.std());
 		unitSystemPanel.add(Box.createHorizontalGlue(), GBC.eol().fill(GBC.HORIZONTAL));
 		tab.add(unitSystemPanel, GBC.eol().fill(GBC.HORIZONTAL));
@@ -377,8 +377,8 @@ public class SettingsGUI extends JDialog {
 				GBC.std());
 		osmHikingPanel.add(osmHikingTicket, GBC.std().insets(2, 0, 10, 0));
 		JLabel osmHikingTicketUrl = new JLabel(I18nUtils.localizedStringForKey("set_mapsrc_config_osmhiking_howto"));
-		osmHikingTicketUrl.addMouseListener(new OpenInWebbrowser(I18nUtils
-				.localizedStringForKey("set_mapsrc_config_osmhiking_howto_url")));
+		osmHikingTicketUrl.addMouseListener(
+				new OpenInWebbrowser(I18nUtils.localizedStringForKey("set_mapsrc_config_osmhiking_howto_url")));
 		osmHikingPanel.add(osmHikingTicketUrl, GBC.eol());
 
 		tab.add(updatePanel, GBC.eol().fill(GBC.HORIZONTAL));
@@ -438,14 +438,14 @@ public class SettingsGUI extends JDialog {
 		MapSourcesManager msManager = MapSourcesManager.getInstance();
 
 		enabledMapSourcesModel = new MapSourcesListModel(msManager.getEnabledOrderedMapSources());
-		enabledMapSources = new JList(enabledMapSourcesModel);
+		enabledMapSources = new JList<>(enabledMapSourcesModel);
 		JScrollPane leftScrollPane = new JScrollPane(enabledMapSources, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
 				JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
 		leftPanel.add(leftScrollPane, BorderLayout.CENTER);
 
 		disabledMapSourcesModel = new MapSourcesListModel(msManager.getDisabledMapSources());
 		disabledMapSourcesModel.sort();
-		disabledMapSources = new JList(disabledMapSourcesModel);
+		disabledMapSources = new JList<>(disabledMapSourcesModel);
 		JScrollPane rightScrollPane = new JScrollPane(disabledMapSources, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
 				JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
 		rightPanel.add(rightScrollPane, BorderLayout.CENTER);
@@ -556,14 +556,15 @@ public class SettingsGUI extends JDialog {
 		atlasOutputDirectory = new JTextField();
 		atlasOutputDirectory.setToolTipText(String.format(I18nUtils.localizedStringForKey("set_directory_output_tips"),
 				settings.getAtlasOutputDirectory()));
-		JButton selectAtlasOutputDirectory = new JButton(I18nUtils.localizedStringForKey("set_directory_output_select"));
+		JButton selectAtlasOutputDirectory = new JButton(
+				I18nUtils.localizedStringForKey("set_directory_output_select"));
 		selectAtlasOutputDirectory.addActionListener(new ActionListener() {
 
 			public void actionPerformed(ActionEvent e) {
 				JDirectoryChooser dc = new JDirectoryChooser();
 				dc.setCurrentDirectory(settings.getAtlasOutputDirectory());
-				if (dc.showDialog(SettingsGUI.this,
-						I18nUtils.localizedStringForKey("set_directory_output_select_dlg_title")) != JFileChooser.APPROVE_OPTION)
+				if (dc.showDialog(SettingsGUI.this, I18nUtils
+						.localizedStringForKey("set_directory_output_select_dlg_title")) != JFileChooser.APPROVE_OPTION)
 					return;
 				atlasOutputDirectory.setText(dc.getSelectedFile().getAbsolutePath());
 			}
@@ -582,16 +583,17 @@ public class SettingsGUI extends JDialog {
 		GBC gbc_eolh = GBC.eol().fill(GBC.HORIZONTAL);
 		JPanel panel = new JPanel(new GridBagLayout());
 		panel.setBorder(createSectionBorder(I18nUtils.localizedStringForKey("set_net_connection")));
-		threadCount = new JComboBox(THREADCOUNT_LIST);
+		threadCount = new JComboBox<>(THREADCOUNT_LIST);
 		threadCount.setMaximumRowCount(THREADCOUNT_LIST.length);
 		panel.add(threadCount, GBC.std().insets(5, 5, 5, 5).anchor(GBC.EAST));
-		panel.add(new JLabel(I18nUtils.localizedStringForKey("set_net_connection_desc")), GBC.eol()
-				.fill(GBC.HORIZONTAL));
+		panel.add(new JLabel(I18nUtils.localizedStringForKey("set_net_connection_desc")),
+				GBC.eol().fill(GBC.HORIZONTAL));
 
-		bandwidth = new JComboBox(Bandwidth.values());
+		bandwidth = new JComboBox<>(Bandwidth.values());
 		bandwidth.setMaximumRowCount(bandwidth.getItemCount());
 		panel.add(bandwidth, GBC.std().insets(5, 5, 5, 5));
-		panel.add(new JLabel(I18nUtils.localizedStringForKey("set_net_bandwidth_desc")), GBC.eol().fill(GBC.HORIZONTAL));
+		panel.add(new JLabel(I18nUtils.localizedStringForKey("set_net_bandwidth_desc")),
+				GBC.eol().fill(GBC.HORIZONTAL));
 
 		backGround.add(panel, gbc_eolh);
 
@@ -602,7 +604,7 @@ public class SettingsGUI extends JDialog {
 		panel = new JPanel(new GridBagLayout());
 		panel.setBorder(createSectionBorder(I18nUtils.localizedStringForKey("set_net_proxy")));
 		final JLabel proxyTypeLabel = new JLabel(I18nUtils.localizedStringForKey("set_net_proxy_settings"));
-		proxyType = new JComboBox(ProxyType.values());
+		proxyType = new JComboBox<>(ProxyType.values());
 		proxyType.setSelectedItem(settings.getProxyType());
 
 		final JLabel proxyHostLabel = new JLabel(I18nUtils.localizedStringForKey("set_net_proxy_host"));
@@ -777,9 +779,10 @@ public class SettingsGUI extends JDialog {
 			MainGUI.getMainGUI().checkAndSaveSettings();
 		} catch (Exception e) {
 			log.error("Error saving settings to file", e);
-			JOptionPane.showMessageDialog(null, String.format(I18nUtils.localizedStringForKey("set_error_saving_msg"),
-					e.getClass().getSimpleName()), I18nUtils.localizedStringForKey("set_error_saving_title"),
-					JOptionPane.ERROR_MESSAGE);
+			JOptionPane.showMessageDialog(null,
+					String.format(I18nUtils.localizedStringForKey("set_error_saving_msg"),
+							e.getClass().getSimpleName()),
+					I18nUtils.localizedStringForKey("set_error_saving_title"), JOptionPane.ERROR_MESSAGE);
 		}
 
 		MainGUI.getMainGUI().previewMap.repaint();
@@ -881,8 +884,9 @@ public class SettingsGUI extends JDialog {
 							JOptionPane.INFORMATION_MESSAGE);
 					break;
 				default:
-					JOptionPane.showMessageDialog(SettingsGUI.this, String.format(
-							I18nUtils.localizedStringForKey("set_mapsrc_config_online_update_msg_done"), result),
+					JOptionPane.showMessageDialog(SettingsGUI.this,
+							String.format(I18nUtils.localizedStringForKey("set_mapsrc_config_online_update_msg_done"),
+									result),
 							I18nUtils.localizedStringForKey("set_mapsrc_config_online_update_done"),
 							JOptionPane.INFORMATION_MESSAGE);
 				}
