@@ -39,6 +39,7 @@ import mobac.program.interfaces.AtlasInterface;
 import mobac.program.interfaces.DownloadJobListener;
 import mobac.program.interfaces.DownloadableElement;
 import mobac.program.interfaces.FileBasedMapSource;
+import mobac.program.interfaces.InitializableMapSource;
 import mobac.program.interfaces.LayerInterface;
 import mobac.program.interfaces.MapInterface;
 import mobac.program.interfaces.MapSource;
@@ -267,6 +268,11 @@ public class AtlasThread extends Thread
 		jobsPermanentError = 0;
 
 		ap.initMapDownload(map);
+
+		if (map.getMapSource() instanceof InitializableMapSource) {
+			((InitializableMapSource) map.getMapSource()).initialize();
+		}
+
 		if (currentThread().isInterrupted())
 			throw new InterruptedException();
 
