@@ -21,12 +21,15 @@ import static mobac.gui.MainGUI.LEFT_PANEL_MIN_SIZE;
 import java.awt.Dimension;
 import java.awt.Point;
 import java.awt.Toolkit;
-import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
+import java.io.OutputStreamWriter;
+import java.io.StringWriter;
+import java.io.Writer;
 import java.net.Authenticator;
 import java.net.PasswordAuthentication;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashSet;
@@ -324,23 +327,20 @@ public class Settings {
 		JAXBContext context = JAXBContext.newInstance(Settings.class);
 		Marshaller m = context.createMarshaller();
 		m.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
-		ByteArrayOutputStream bo = null;
-		FileOutputStream fo = null;
-		try {
-			// First we write to a buffer and if that works be write the buffer
-			// to disk. Direct writing to file may result in an defect xml file
-			// in case of an error
-			bo = new ByteArrayOutputStream();
-			m.marshal(getInstance(), bo);
-			fo = new FileOutputStream(FILE);
-			fo.write(bo.toByteArray());
-			fo.close();
-			SETTINGS_LAST_MODIFIED = FILE.lastModified();
+
+		// First we write to a buffer and if that works be write the buffer
+		// to disk. Direct writing to file may result in an defect xml file
+		// in case of an error
+		StringWriter sw = new StringWriter(4096);
+		m.marshal(getInstance(), sw);
+		String settingsString = sw.toString();
+
+		try (Writer writer = new OutputStreamWriter(new FileOutputStream(FILE), StandardCharsets.UTF_8)) {
+			writer.write(settingsString);
 		} catch (IOException e) {
 			throw new JAXBException(e);
-		} finally {
-			Utilities.closeStream(fo);
 		}
+		SETTINGS_LAST_MODIFIED = FILE.lastModified();
 	}
 
 	public static void loadOrQuit() {
